@@ -1,6 +1,6 @@
 from .daemon import DaemonController
 
 if __name__ == "__main__":
-    controller = DaemonController()
+    controller = DaemonController('DEVLPR')
     controller.start(True)
     
\ No newline at end of file
